@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2013 by Barry A. Warsaw
+# Copyright (C) 1998-2014 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -26,7 +26,7 @@ __all__ = [
 
 import re
 
-from flufl.enum import Enum
+from enum import Enum
 from io import BytesIO
 from zope.interface import implementer
 
