@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2013 by Barry A. Warsaw
+# Copyright (C) 2001-2014 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -58,6 +58,10 @@ PATTERNS = [
     (_c('This is an advisory-only email'),
      _c('has been postponed'),
      _c('"(?P<addr>[^"]+)"')),
+    # kundenserver.de
+    (_c('not yet been delivered'),
+     _c('No action is required on your part'),
+     _c(r'\s*<?(?P<addr>\S+@[^>\s]+)>?\s*')),
     # Next one goes here...
     ]
 
